@@ -6,19 +6,23 @@
 pub mod command;
 mod errors;
 pub mod nodes;
-#[cfg(feature = "storage")]
-mod store;
+#[deny(missing_docs)]
+/// Traits for notedown
 pub mod traits;
+#[deny(missing_docs)]
+/// Value and value types of notedown
+pub mod value;
 
 pub use self::{
+    command::Command,
     errors::{NoteError, NoteErrorKind, Result},
     nodes::{ASTKind, ASTNode, ASTNodes},
+    value::Value,
 };
 
-#[cfg(feature = "storage")]
-pub use self::store::*;
-
 pub mod utils {
-    pub use text_utils::*;
+    pub use itertools;
+    pub use lsp_types;
+    pub use text_utils;
     pub use yggdrasil_shared::records::*;
 }
